==> estateplat-common-1.2.3-20180102.074335-1-sources.jar: cn/gtmap/estateplat/service/config/QlztService.java <==
package cn.gtmap.estateplat.service.config;
/*
 * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
 * @version 1.0, 2017/12/11
 * @description 权利状态服务
 */

import cn.gtmap.estateplat.model.server.core.BdcZs;

import java.util.List;

public interface QlztService {

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param cqzh(不动产权证号，房产证号，土地证号）；xmly：数据来源
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByCqzh(String cqzh,String xmly);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param proid 项目主键
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByProid(String proid);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param fwid 房屋id
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByFwid(String fwid);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param tdid
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByTdid(String tdid);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param bdcdyhList(不动产单元号）bdclx：不动产类型
     * @return 返回信息
     * @description 更新不动产单元表权利状态
     */
    String updateBdcdyZtByBdcdyh(List<String> bdcdyhList, String bdclx);
    /**
    *@Author:<a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
    *@param:List<bdcZs>
    *@Description:通过参数证书删除证书证明状态管理记录
    *@Date 9:57 2018/1/2
    */
    Boolean updateZszmZtByDeleteEnvent(List<BdcZs> bdcZsList);
}

==> estateplat-common-1.2.3-20180103.105715-4-sources.jar: cn/gtmap/estateplat/service/config/QlztService.java <==
package cn.gtmap.estateplat.service.config;
/*
 * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
 * @version 1.0, 2017/12/11
 * @description 权利状态服务
 */

import cn.gtmap.estateplat.model.server.core.BdcZs;

import java.util.List;
import java.util.Map;

public interface QlztService {

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param cqzh(不动产权证号，房产证号，土地证号）；xmly：数据来源
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByCqzh(String cqzh,String xmly);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param proid 项目主键
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByProid(String proid);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param fwid 房屋id
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByFwid(String fwid);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param tdid
     * @return 返回信息
     * @description 更新证书证明查询表权利状态
     */
    Boolean updateZszmZtByTdid(String tdid);

    /**
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @param bdcdyhList(不动产单元号）bdclx：不动产类型
     * @return 返回信息
     * @description 更新不动产单元表权利状态
     */
    String updateBdcdyZtByBdcdyh(List<String> bdcdyhList, String bdclx);
    /**
    *@Author:<a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
    *@param:List<bdcZs>
    *@Description:通过参数证书删除证书证明状态管理记录
    *@Date 9:57 2018/1/2
    */
    Boolean updateZszmZtByDeleteEnvent(List<BdcZs> bdcZsList);


    /**
     * @param wiid 流程id
     * @return 返回信息
     * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
     * @description 获取流程所有相关证号
     */
    List<Map<String, Object>> listCqzt(String wiid);
}
